==> account-api-core-8.0.1-alpha.0.tgz: package/lib/servers/services/AccountProxyService.js <==
import {__decorate,__param,__metadata}from'tslib';import {injectable,inject}from'inversify';import {ServiceBroker}from'moleculer';import {CommonType}from'@common-stack/core';import'@cdm-logger/core';import {BaseProxyService}from'@common-stack/store-mongo';import {IMoleculerServiceName,IAccountServiceAction}from'@adminide-stack/core';let AccountProxyService = class AccountProxyService extends BaseProxyService {
    logger;
    topic = IMoleculerServiceName.AccountUser;
    constructor(broker, logger) {
        super(broker, logger);
    }
    getUserTokens(userId, tokenType) {
        throw new Error('Method not implemented.');
    }
    dispatchUserVerificationEmail(email, emailVerificationToken) {
        return this.callAction(IAccountServiceAction.DispatchUserVerificationEmail, { email, emailVerificationToken });
    }
    dispatchUserPasswordResetEmail(user, token) {
        return this.callAction(IAccountServiceAction.DispatchUserPasswordResetEmail, { user, token });
    }
    createDefaultAccount(user, optional) {
        return this.callAction(IAccountServiceAction.CreateDefaultAccount, { user, optional });
    }
    updateUserAccount(user, userInfo) {
        return this.callAction(IAccountServiceAction.UpdateAccount, { user, userInfo });
    }
    createAccount(account) {
        return this.callAction(IAccountServiceAction.CreateAccount, { account });
    }
    findAccountById(id) {
        return this.callAction(IAccountServiceAction.FindAccountById, { id });
    }
    findAccountByUser(id) {
        return this.callAction(IAccountServiceAction.FindAccountByUser, { id });
    }
    findAccountByEmail(email) {
        return this.callAction(IAccountServiceAction.FindAccountByEmail, { email });
    }
    getUsers(where) {
        return this.callAction(IAccountServiceAction.GetUsers, { where });
    }
    updateAccount(account) {
        return this.callAction(IAccountServiceAction.UpdateAccount, { account });
    }
    deleteAccount(account) {
        return this.callAction(IAccountServiceAction.DeleteAccount, { account });
    }
    accountOnBoarding(input, context) {
        return this.callAction(IAccountServiceAction.AccountOnBoarding, { input, context });
    }
    deleteUserAccount(id) {
        return this.callAction(IAccountServiceAction.DeleteUserAccount, { id });
    }
    getUserTokenDetails(userId, type) {
        return this.callAction(IAccountServiceAction.GetUserTokenDetails, { userId, type });
    }
    addUserToken(userId, token) {
        return this.callAction(IAccountServiceAction.AddUserToken, { userId, token });
    }
    removeUserToken(userId, token) {
        return this.callAction(IAccountServiceAction.RemoveUserToken, { userId, token });
    }
    getAllUserTokens(userIds, tokenTypes) {
        return this.callAction(IAccountServiceAction.GetAllUserTokens, { userIds, tokenTypes });
    }
    getUserAccountByEmail(email) {
        return this.callAction(IAccountServiceAction.GetUserAccountByEmail, { email });
    }
};
AccountProxyService = __decorate([
    injectable(),
    __param(0, inject(CommonType.MOLECULER_BROKER)),
    __param(1, inject(CommonType.LOGGER)),
    __metadata("design:paramtypes", [ServiceBroker, Object])
], AccountProxyService);export{AccountProxyService};

==> account-api-core-10.0.1-alpha.0.tgz: package/lib/servers/services/AccountProxyService.js <==
import {__decorate,__param,__metadata}from'tslib';import {injectable,inject}from'inversify';import {ServiceBroker}from'moleculer';import {CommonType}from'@common-stack/core';import {BaseProxyService}from'@common-stack/store-mongo';import {IMoleculerServiceName,IAccountServiceAction}from'common/lib/generated/generated-models.js';let AccountProxyService = class AccountProxyService extends BaseProxyService {
    logger;
    topic = IMoleculerServiceName.AccountUser;
    constructor(broker, logger) {
        super(broker, logger);
    }
    getUserTokens(userId, tokenType) {
        throw new Error('Method not implemented.');
    }
    dispatchUserVerificationEmail(email, emailVerificationToken) {
        return this.callAction(IAccountServiceAction.DispatchUserVerificationEmail, { email, emailVerificationToken });
    }
    dispatchUserPasswordResetEmail(user, token) {
        return this.callAction(IAccountServiceAction.DispatchUserPasswordResetEmail, { user, token });
    }
    createDefaultAccount(user, context) {
        return this.callAction(IAccountServiceAction.CreateDefaultAccount, { user, context });
    }
    updateUserAccount(user, userInfo) {
        return this.callAction(IAccountServiceAction.UpdateAccount, { user, userInfo });
    }
    updateUserAccountAliases(input) {
        return this.callAction(IAccountServiceAction.UpdateUserAccountAliases, { input });
    }
    createAccount(account) {
        return this.callAction(IAccountServiceAction.CreateAccount, { account });
    }
    findAccountById(id) {
        return this.callAction(IAccountServiceAction.FindAccountById, { id });
    }
    findAccountByUser(id, context) {
        return this.callAction(IAccountServiceAction.FindAccountByUser, { id, context });
    }
    findAccountByEmail(email) {
        return this.callAction(IAccountServiceAction.FindAccountByEmail, { email });
    }
    getUsers(where) {
        return this.callAction(IAccountServiceAction.GetUsers, { where });
    }
    updateAccount(account) {
        return this.callAction(IAccountServiceAction.UpdateAccount, { account });
    }
    deleteAccount(account) {
        return this.callAction(IAccountServiceAction.DeleteAccount, { account });
    }
    accountOnBoarding(input, context) {
        return this.callAction(IAccountServiceAction.AccountOnBoarding, { input, context });
    }
    deleteUserAccount(id) {
        return this.callAction(IAccountServiceAction.DeleteUserAccount, { id });
    }
    getUserTokenDetails(userId, type) {
        return this.callAction(IAccountServiceAction.GetUserTokenDetails, { userId, type });
    }
    addUserToken(userId, token) {
        return this.callAction(IAccountServiceAction.AddUserToken, { userId, token });
    }
    removeUserToken(userId, token) {
        return this.callAction(IAccountServiceAction.RemoveUserToken, { userId, token });
    }
    getAllUserTokens(userIds, tokenTypes) {
        return this.callAction(IAccountServiceAction.GetAllUserTokens, { userIds, tokenTypes });
    }
    getUserAccountByEmail(email) {
        return this.callAction(IAccountServiceAction.GetUserAccountByEmail, { email });
    }
    getAccountsLoginRecords(skip, limit) {
        return this.callAction(IAccountServiceAction.GetAccountsLoginRecords, { skip, limit });
    }
    addAccountLoginHistoryRecord(args) {
        return this.callAction(IAccountServiceAction.AddAccountsLoginHistoryRecords, { args });
    }
    updateUserProfile(account, context) {
        return this.callAction(IAccountServiceAction.UpdateUserProfile, { account, context });
    }
};
AccountProxyService = __decorate([
    injectable(),
    __param(0, inject(CommonType.MOLECULER_BROKER)),
    __param(1, inject(CommonType.LOGGER)),
    __metadata("design:paramtypes", [ServiceBroker, Object])
], AccountProxyService);export{AccountProxyService};
